# Database Migrations

This directory contains database migration scripts using Alembic.

## Directory Structure

```
migrations/
├── env.py              # Alembic environment configuration
├── script.py.mako      # Migration script template
└── versions/           # Migration script versions
```

## Usage

1. Create a new migration:
```bash
alembic revision --autogenerate -m "description"
```

2. Apply migrations:
```bash
alembic upgrade head
```

3. Revert migrations:
```bash
alembic downgrade -1    # Revert last migration
alembic downgrade base  # Revert all migrations
```

## Configuration

- Database URL is read from environment variable `POSTGRES_URI`
- Migration scripts are stored in `versions/` directory
- Models are automatically detected from `adpa.database.models`

## Best Practices

1. Always review autogenerated migrations
2. Test migrations in development before production
3. Include both upgrade and downgrade operations
4. Keep migrations atomic and focused
5. Document complex migration logic
6. Use appropriate transaction boundaries
7. Handle data migrations carefully

## Migration History

### 001_initial.py
- Created initial schema with users, queries, and query_results tables
- Added basic user management functionality
- Added query tracking and results storage

### 002_merge_old_migrations.py
- Merged migrations from old alembic directory
- Added agents, projects, teams tables
- Added team_assignments and agent_actions tables
- Added constraints for agent types
- Added relationships between agents and projects

## Next Steps

1. Run migrations:
```bash
alembic upgrade head
```

2. Verify database schema:
```sql
\d+ agents
\d+ projects
\d+ teams
\d+ team_assignments
\d+ agent_actions
```

3. Test relationships:
```sql
-- Test project-agent relationship
SELECT a.name, p.name 
FROM agents a 
JOIN projects p ON a.project_id = p.id;

-- Test team assignments
SELECT t.name, a.name, ta.role 
FROM teams t 
JOIN team_assignments ta ON t.id = ta.team_id 
JOIN agents a ON ta.agent_id = a.id;
```
